<template>
  <view>
    <view class="nav_item form-container">
      <form :modelValue="scanFormData">
        <view class="form-group">
          <label class="form-label">移入库位:</label>
         <input class="form-input" placeholder="请扫描库位" type="text"
                v-model="scanFormData.sectionCode"  :focus="focus1"  @confirm="checkKw"  @focus="getFocus(1)"/>
        </view>
        <view class="form-group">
          <label class="form-label">物料条码:</label>
          <input class="form-input" placeholder="请扫描物料条码" type="text"
                 v-model="scanFormData.barcode" :focus="focus2" @confirm="checkWl" @focus="getFocus(2)"/>
        </view>
        <view class="form-group">
          <label class="form-label">物料编码:</label>
          <input class="form-input" disabled="true" type="text" v-model="scanFormData.itemNo"/>
        </view>
        <view class="form-group">
          <label class="form-label">数量:</label>
          <input class="form-input" type="text" v-model="scanFormData.quantity"/>
        </view>
      </form>
    </view>
    <view class="text" v-if="Message">
      <text v-text="Message"></text>
    </view>
</view>
    
</template>

<script>
import {
  broadcastScan
} from '@/utils/scanCode.js';

export default {
  data() {
    return {
	  focus1: true,
	  focus2: false,
	  scanFormData: {sectionCode:"",barcode:""},
	  itemOutNoList: [],
      Message: '',
    }
  },
  methods: {
	  // onLoad 是在页面加载时触发，用于页面的初始化操作，只执行一次
	  onLoad() {
	    // init传入一个回调函数做参数，在扫描时候会将数据传入此方法里，然后处理此方法的自定义业务逻辑
	    broadcastScan.init(this.getScanCode);
		this.getFocus(1);
	  },
	  onUnload() {
	    broadcastScan.stop();
	  },
	  // 在页面展示时触发，用于处理页面显示相关的逻辑，可能会多次执行，包括页面首次展示和从后台切换到前台时
	  onShow() {
	    broadcastScan.start();
	  },
	  onHide() {
	    broadcastScan.stop();
	  },
	  // 自定义扫描的结果回调函数
	  getScanCode(code) {
	     let parseData = code.trim();
	    if (this.focus2) {
	      this.scanFormData.barcode = parseData;
		  //库位检查
		  this.checkWl();
	    } else {
	      this.scanFormData.sectionCode = parseData;
		  //物料检查
		  this.checkKw();
	    }
	  },
	  // 主动触发扫描
	  openScan() {
	    broadcastScan.triggerScan();
	  },
	  //移动焦点
	  getFocus(f) {
		  switch(f){
			  case 1:
			  this.focus1 = true;
			  this.focus2 = false;
			  this.scanFormData.sectionCode = "";
			  break;
			  case 2:
			  this.focus1 = false;
			  this.focus2 = true;
			  this.scanFormData.barcode = "";
			  default:
			  break;
		  }
	  },
	  //检查库位
		checkKw() {
		  	var that=this;
		  	if (!this.scanFormData.barcode) {
		  	}
		  	let userName = this.$loginInfo.account;
		  	this.$post({
		  	  url: "/MesDepotSections/ScanInDepotSectionsName",
		  	  data: {
		  	    sectionCode:that.scanFormData.sectionCode,
		  	  }
		  	}).then(res => {
		  	    that.getFocus(2);
		  	});	
		  },
		 //移位
		checkWl(){
				var that=this;
				let userName = this.$loginInfo.account;
				 that.$post({
				   url: "/MesInvItemMoves/ScanInBarcode",
				   data: {
				     userName: userName,
					 sectionCode:that.scanFormData.sectionCode,
					 barcode:that.scanFormData.barcode,
				   }
				 }).then(res => {
					 //待赋值
					  that.scanFormData.itemNo="";
					  that.scanFormData.quantity="";
					  that.getFocus(2);
				 });
			},
  }
}
</script>

<style>
.pdmg0{padding: 0px !important;margin: 0px !important;}
.form-group {
  display: flex;
  align-items: center;
  border-bottom: 1px solid #c9c9c9;
}

.form-label {
  margin-bottom: 0;
  padding: 5px;
}

.form-input {
  flex: 1;
  margin-bottom: 0;
  padding: 5px;
}

.picker {
  flex: 1;
  margin-bottom: 0;
  padding: 5px;
  font-size: 12px;
}

.uni-form-item {
  display: flex;
  border-bottom: 1px solid #c9c9c9;
}

.edit {
  background-color: white;
}

/* 默认样式 */
.list-container {
  height: 60vh;
  /* 设置列表容器的高度为剩余空间，并减去表单容器的高度 */
  overflow-y: auto;
  /* 允许列表容器垂直滚动 */
  padding: 10px;
  /* 可选：添加一些内边距，使列表内容更美观 */
}

/* 在小屏幕设备上，重置高度为适应屏幕 */
@media (max-width: 768px) {
  .list-container {
    height: calc(100vh - 500px);
    /* 适当调整高度 */
  }
}


.form-container {
  padding: 10px;
  /* 可选：添加一些内边距，使表单内容更美观 */
}

.th {
  background-color: lightskyblue;
  color: #FFFFFF;
}

.text {
  background-color: #ffee6f;
}

.plus-button {
  line-height: 59px;
  font-size: 24px;
  cursor: pointer;
  z-index: 1000;
  margin-bottom: 10px;
}

.overlay {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.5);
  display: flex;
  justify-content: center;
  align-items: center;
}

.popup {
  background-color: #fff;
  padding: 20px;
  border: 1px solid #ccc;
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
  width: 68vw;
  /* 设置宽度为视口宽度的80% */
  height: 25vh;
  /* 设置高度为视口高度的80% */
}

.container {
  display: flex;
  flex-direction: column;
}

.tab-bar {
  display: flex;
  justify-content: space-around;
  background-color: #f5f5f5;
  padding: 10px;
  border-bottom: 1px solid #ccc;
}

.tab-item {
  flex: 1;
  text-align: center;
  padding: 10px;
  border-radius: 5px;
  background-color: #fff;
  color: #007aff;
  cursor: pointer;
  font-size: 16px;
  transition: background-color 0.3s, color 0.3s;
}

.tab-item.active {
  background-color: #007aff;
  color: #fff;
  font-weight: bold;
}

.content {
  flex: 1;
  padding: 10px;
}

.tab-content {
  padding: 10px;
}
</style>